@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,7 +10,8 @@
 class QFile;
 class QDomDocument;
 
-namespace EvolutionUtil {
+namespace EvolutionUtil
+{
 bool loadInDomDocument(QFile *file, QDomDocument &doc);
 bool loadInDomDocument(const QString &file, QDomDocument &doc);
 }
